# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ FOLDER DEFINITIONS -----------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
from abaqus import *
from abaqusConstants import *
import __main__
import section
import regionToolset
import displayGroupMdbToolset as dgm
import part
import material
import assembly
import step
import interaction
import load
import mesh
import optimization
import job
import sketch
import visualization
import xyPlot
import displayGroupOdbToolset as dgo
import connectorBehavior
import numpy as np
import math
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ INPUT VALUES -----------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# CABLE GEOMETRY [m]
a = 285.0						# Horizontal distance between left tower and anchorage
b = 1220.0						# Length of middle span
c = 285.0						# Horizontal distance between right tower and anchorage
d = a/1.8						# Height between left tower and anchorage
e = 123.0 - 7						# Height from tower to midspan of cables
f = c/1.8						# Height between right tower and anchorage
g = 34.0						# Width between cables at left anchorages
h = 29.5						# Width between cables at midspan
i = 34.0						# Width between cables at right anchorages
k = 1.6							# Width between cables at tower tops
# TOWER GEOMETRY [m]
gap= 6.5						# Vertical distance between cables and girder at the midspan
j= 69.0							# Vertical distance between girder and bottom of towers
# GIRDER GEOMETRY [m]
vert_curv= 7.5 + 7				# Height between lowest and highest parts of girder. NB must be either .0 or .5 due to tower list
# NODE SPACING (x-dir) [m]
spacing_side_span = 25.0		# Horizontal spacing of cable nodes at outer part of towers
spacing_mid_span = 12.0			# Horizontal spacing of cable nodes(hangers) at the midspan
spacing_girder = 2.0			# Horizontal spacing of girder nodes
# MESH SEED SIZE [m]
sz_towers = 500.0
sz_rigels = 20.0
sz_cables = 500.0
sz_girder = 10.0
sz_hangers = 500000.0
sz_coneltowers = 500.0
sz_conelgirder = 500.0
# GIRDER MATERIAL PROPERTIES
#Densitygirder = 7850.0			# STEEL
#Ematgirder = 210e9				# STEEL
Densitygirder = 2700.0			# ALUMINUM
Ematgirder = 70e9				# ALUMINUM
#NB maa oppdatere density ogsaa i keywordBlock.replace


# NAME AND DIRECTORY OF JOB - name accordingly
workDir=''
jobName=''

# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ GENERATING LISTS OF COORDINATES ----------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# CABLES
n_divisions_mid = b/spacing_mid_span
n_divisions_side1 = a/spacing_side_span
n_divisions_side2 = c/spacing_side_span

x1 = np.arange(-b/2, b/2, spacing_mid_span)
if n_divisions_mid%1 == 0:
    pass
else:
    delay = (b - math.floor(b / spacing_mid_span) * spacing_mid_span) * 0.5
    x1 = x1 + delay
    x1 = np.append(-b/2, x1)
    x1 = np.append(x1, b/2)
y1 = -(2*(h-k)/(b*b))*x1*x1+h/2
z1 = (4*e/(b*b))*x1*x1

x2 = np.arange(-b//2, b//2, spacing_mid_span)
if n_divisions_mid%1 == 0:
    pass
else:
    delay = (b - math.floor(b / spacing_mid_span) * spacing_mid_span) * 0.5
    x2 = x2 + delay
    x2 = np.append(-b/2, x2)
    x2 = np.append(x2, b/2)
y2 = (2*(h-k)/(b*b))*x2*x2-h/2
z2 = (4*e/(b*b))*x2*x2

x3 = np.arange(-(0.5*b+a), (-0.5*b+1), spacing_side_span)
if n_divisions_side1%1 == 0:
	pass
else:
	delay_side1 = (a - math.floor(a/spacing_side_span) * spacing_side_span)
	x3 = x3 + delay_side1
	x3 = np.append(-(0.5*b+a), x3)
y3 = -(g-k)/(2*a)*x3-(b*(g-k)/(4*a))+(k/2)
z3 = d/a*x3+(e+b*d/(2*a))

x4 = np.arange(-(0.5*b+a), (-0.5*b+1), spacing_side_span)
if n_divisions_side1%1 == 0:
	pass
else:
	delay_side1 = (a - math.floor(a/spacing_side_span) * spacing_side_span)
	x4 = x4 + delay_side1
	x4 = np.append(-(0.5*b+a), x4)
y4 = (g-k)/(2*a)*x4+(b*(g-k)/(4*a))-(k/2)
z4 = d/a*x4+(e+b*d/(2*a))

x5 = np.arange((0.5*b), (0.5*b+c+1), spacing_side_span)
if n_divisions_side2%1 == 0:
	pass
else:
	x5 = np.append(x5, (0.5*b+c))
y5 = (i-k)/(2*c)*x5-(b*(i-k)/(4*c))+(k/2)
z5 = -f/c*x5+(e+b*f/(2*c))

x6 = np.arange((0.5*b), (0.5*b+c+1), spacing_side_span)
if n_divisions_side2%1 == 0:
	pass
else:
	x6 = np.append(x6, (0.5*b+c))
y6 = -(i-k)/(2*c)*x6+b*(i-k)/(4*c)-(k/2)
z6 = -f/c*x6+(e+b*f/(2*c))

# Join into two main cables
x3 = np.delete(x3, -1)
x1 = np.delete(x1, -1)
x1_main = np.append(x3, x1)
x1_main = np.append(x1_main, x5)  # x-vector cable 1
y3 = np.delete(y3, -1)
y1 = np.delete(y1, -1)
y1_main = np.append(y3, y1)
y1_main = np.append(y1_main, y5)  # y-vector cable 1
z3 = np.delete(z3, -1)
z1 = np.delete(z1, -1)
z1_main = np.append(z3, z1)
z1_main = np.append(z1_main, z5)  # z-vector cable 1
x4 = np.delete(x4, -1)
x2 = np.delete(x2, -1)
x2_main = np.append(x4, x2)
x2_main = np.append(x2_main, x6)  # x-vector cable 2
y4 = np.delete(y4, -1)
y2 = np.delete(y2, -1)
y2_main = np.append(y4, y2)
y2_main = np.append(y2_main, y6)  # y-vector cable 2
z4 = np.delete(z4, -1)
z2 = np.delete(z2, -1)
z2_main = np.append(z4, z2)
z2_main = np.append(z2_main, z6)  # z-vector cable 2

cablelist1 = list(zip(x1_main, y1_main, z1_main))
cablelist2 = list(zip(x2_main, y2_main, z2_main))

# PYLONS/TOWERS
x7=np.linspace(-b/2,-b/2,(206*2+1))
x8=np.linspace(b/2,b/2,(206*2+1))
z7=np.linspace(-j-gap-vert_curv,e,(206*2+1))
y7=h/(2*e)*z7-h/2
y8=-h*z7/(2*e)+h/2

pylon1_x = np.append(x7, np.delete(x7, -1))
pylon1_y = np.append(y7, np.delete(y8[::-1],0))
pylon1_z = np.append(z7, np.delete(z7[::-1],0))
pylon1 = list(zip(pylon1_x, pylon1_y, pylon1_z))

pylon2_x = np.append(x8, np.delete(x8, -1))
pylon2_y = np.append(y7, np.delete(y8[::-1],0))
pylon2_z = np.append(z7, np.delete(z7[::-1],0))
pylon2 = list(zip(pylon2_x, pylon2_y, pylon2_z))

# GIRDER
x9 = np.arange(-b/2+2.0, (b/2)+1, spacing_girder)
n_divisions_girder = b/spacing_girder

if n_divisions_girder%1 == 0:
    pass
else:
    delay = (b - math.floor(b / spacing_girder) * spacing_girder) * 0.5
    x9 = x9 + delay
    x9 = np.append(-b/2, x9)
    x9 = np.append(x9, b/2)

x9 = np.append(-b/2, x9)
x9 = np.append(x9, b/2)
x9 = np.delete(x9,-1) #Selvkomponert
y9=np.linspace(0,0,len(x9))
z9=-vert_curv/((b/2)**2)*(x9**2)-gap

deck = list(zip(x9, y9, z9))
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ INITIALIZATION ---------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
bridge = mdb.models['Model-1']
myAssembly = bridge.rootAssembly
myAssembly.DatumCsysByDefault(CARTESIAN)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TOWERS -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='Tower1', dimensionality=THREE_D, type=DEFORMABLE_BODY)
tower1 = bridge.parts['Tower1']
tower1.WirePolyLine(points=pylon1, mergeType=SEPARATE, meshable=ON)

bridge.Part(name='Tower2', dimensionality=THREE_D, type=DEFORMABLE_BODY)
tower2 = bridge.parts['Tower2']
tower2.WirePolyLine(points=pylon2, mergeType=SEPARATE, meshable=ON)

# PART SETS
set_tower1 = bridge.parts['Tower1'].Set(name = 'Tower1 set', edges = tower1.edges)
set_tower2 = bridge.parts['Tower2'].Set(name = 'Tower2 set', edges = tower2.edges)

# SECTION ASSIGNMENT
bridge.BoxProfile(name='profileTowers', a = 5.0, b= 5.0, uniformThickness = ON, t1 = 1.0)
Emat2=35000e6
Gmat2=Emat2/(2*(1+0.2))
my2ndsection = bridge.BeamSection(name = 'sectionTowers', profile = 'profileTowers', poissonRatio=0.2, integration=BEFORE_ANALYSIS,
	table=((Emat2, Gmat2), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
	consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
	temperatureDependency=OFF, thermalExpansion=OFF, density = 2400.0)

bridge.parts['Tower1'].SectionAssignment(region = set_tower1, sectionName = 'sectionTowers')
bridge.parts['Tower1'].assignBeamSectionOrientation(region = set_tower1, method = N1_COSINES, n1 = (0.0, 0.0, -1.0))
bridge.parts['Tower2'].SectionAssignment(region = set_tower2, sectionName = 'sectionTowers')
bridge.parts['Tower2'].assignBeamSectionOrientation(region = set_tower2, method = N1_COSINES, n1 = (0.0, 0.0, -1.0))

# ASSEMBLY
inst_tower1 = myAssembly.Instance(name='Tower1 instance', part=tower1, dependent=ON)
inst_tower2 = myAssembly.Instance(name='Tower2 instance', part=tower2, dependent=ON)

# BCs
vert_tower1_bottoms = inst_tower1.vertices.findAt(((pylon1[0]), ), ((pylon1[-1]), ),)
vert_tower2_bottoms = inst_tower2.vertices.findAt(((pylon2[0]), ), ((pylon2[-1]), ),)

set_vert_tower1_bottoms = myAssembly.Set(name = 'setVertices Tower1_bottoms', vertices = vert_tower1_bottoms)
set_vert_tower2_bottoms = myAssembly.Set(name = 'setVertices Tower2_bottoms', vertices = vert_tower2_bottoms)

bridge.EncastreBC(createStepName = 'Initial', localCsys = None, name = 'towersbottomsBC1', region = set_vert_tower1_bottoms)
bridge.EncastreBC(createStepName = 'Initial', localCsys = None, name = 'towersbottomsBC2', region = set_vert_tower2_bottoms)

# MESH 
tower1.seedPart(size=sz_towers, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
tower1.setElementType(regions=set_tower1, elemTypes=(elemType1,))
tower1.generateMesh()
 
tower2.seedPart(size=sz_towers, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
tower2.setElementType(regions=set_tower2, elemTypes=(elemType1,))
tower2.generateMesh()
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ RIGELS -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
blabla = np.argwhere(z7 == -gap-vert_curv)
punkt1_tower1 = tower1.vertices[blabla[0][0]].pointOn[0]
punkt2_tower1 = tower1.vertices[len(pylon1_z)-1-blabla[0][0]].pointOn[0]
punkt1_tower2 = tower2.vertices[blabla[0][0]].pointOn[0]
punkt2_tower2 = tower2.vertices[len(pylon2_z)-1-blabla[0][0]].pointOn[0]

# PART CREATION
bridge.Part(name='Rigel1', dimensionality=THREE_D, type=DEFORMABLE_BODY)
rigel1 = bridge.parts['Rigel1']
rigel1.WirePolyLine(points = (punkt1_tower1, (-0.5*b, 0, -gap-vert_curv), punkt2_tower1), mergeType = IMPRINT, meshable = ON)

bridge.Part(name='Rigel2', dimensionality=THREE_D, type=DEFORMABLE_BODY)
rigel2 = bridge.parts['Rigel2']
rigel2.WirePolyLine(points = (punkt1_tower2, (0.5*b, 0, -gap-vert_curv), punkt2_tower2), mergeType = IMPRINT, meshable = ON)

# PART SETS
set_rigel1 = bridge.parts['Rigel1'].Set(name = 'Rigel1 set', edges = rigel1.edges)
set_rigel2 = bridge.parts['Rigel2'].Set(name = 'Rigel2 set', edges = rigel2.edges)

# SECTION ASSIGNMENT
bridge.BoxProfile(name='profileRigels', a = 5.0, b= 5.0, uniformThickness = ON, t1 = 0.5)
Emat2=36000e6
Gmat2=Emat2/(2*(1+0.2))
my2ndsection = bridge.BeamSection(name = 'sectionRigels', profile = 'profileRigels', poissonRatio=0.2, integration=BEFORE_ANALYSIS,
	table=((Emat2, Gmat2), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
	consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
	temperatureDependency=OFF, thermalExpansion=OFF, density = 2400.0)

bridge.parts['Rigel1'].SectionAssignment(region = set_rigel1, sectionName = 'sectionRigels')
bridge.parts['Rigel1'].assignBeamSectionOrientation(region = set_rigel1, method = N1_COSINES, n1 = (0.0, 0.0, -1.0))
bridge.parts['Rigel2'].SectionAssignment(region = set_rigel2, sectionName = 'sectionRigels')
bridge.parts['Rigel2'].assignBeamSectionOrientation(region = set_rigel2, method = N1_COSINES, n1 = (0.0, 0.0, -1.0))

# ASSEMBLY
inst_rigel1 = myAssembly.Instance(name='Rigel1 instance', part=rigel1, dependent=ON)
inst_rigel2 = myAssembly.Instance(name='Rigel2 instance', part=rigel2, dependent=ON)

# MESH 
rigel1.seedPart(size=sz_rigels, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
rigel1.setElementType(regions=set_rigel1, elemTypes=(elemType1,))
rigel1.generateMesh()
 
rigel2.seedPart(size=sz_rigels, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
rigel2.setElementType(regions=set_rigel2, elemTypes=(elemType1,))
rigel2.generateMesh()
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ CABLES -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='Cable1', dimensionality=THREE_D, type=DEFORMABLE_BODY)
cable1 = bridge.parts['Cable1']
cable1.WirePolyLine(points=cablelist1, mergeType=SEPARATE, meshable=ON)
bridge.Part(name='Cable2', dimensionality=THREE_D, type=DEFORMABLE_BODY)
cable2 = bridge.parts['Cable2']
cable2.WirePolyLine(points=cablelist2, mergeType=SEPARATE, meshable=ON)

# PART SETS
set_cable1 = bridge.parts['Cable1'].Set(name = 'Cable1 set', edges = cable1.edges)
set_cable2 = bridge.parts['Cable2'].Set(name = 'Cable2 set', edges = cable2.edges)

# SECTION ASSIGNMENT
bridge.GeneralizedProfile(name='profileCables', area=0.3257, i11=0.0084, i12=0.0, i22=0.0084, j=0.0169, gammaO=0.0,  gammaW=0.0)
Emat=200e9
Gmat=Emat/(2*(1+0.3))
mySection=bridge.BeamSection(name='sectionCables', profile='profileCables',									
    poissonRatio=0.3, integration=BEFORE_ANALYSIS,
	table=((Emat, Gmat), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
	consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
	temperatureDependency=OFF, thermalExpansion=OFF, density = 7850.0)

bridge.parts['Cable1'].SectionAssignment(region = set_cable1, sectionName = 'sectionCables')
bridge.parts['Cable1'].assignBeamSectionOrientation(region = set_cable1, method = N1_COSINES, n1 = (0.0, 1.0, 0.0))
bridge.parts['Cable2'].SectionAssignment(region = set_cable2, sectionName = 'sectionCables')
bridge.parts['Cable2'].assignBeamSectionOrientation(region = set_cable2, method = N1_COSINES, n1 = (0.0, 1.0, 0.0))
	
# ASSEMBLY
inst_cable1 = myAssembly.Instance(name='Cable1 instance', part=cable1, dependent=ON)
inst_cable2 = myAssembly.Instance(name='Cable2 instance', part=cable2, dependent=ON)

# BCs
vert_cable1_anchorage = inst_cable1.vertices.findAt(((cablelist1[0]), ), ((cablelist1[-1]), ),) 
vert_cable2_anchorage = inst_cable2.vertices.findAt(((cablelist2[0]), ), ((cablelist2[-1]), ),)
vert_cable1_midspan = inst_cable1.vertices.findAt(((x1[np.argmin(z1)], y1[np.argmin(z1)], z1[np.argmin(z1)]), ),)
vert_cable2_midspan = inst_cable2.vertices.findAt(((x2[np.argmin(z2)], y2[np.argmin(z2)], z2[np.argmin(z2)]), ),)

set_vert_cable1_anchorage = myAssembly.Set(name = 'setVertices Cable1_Anchorage', vertices = vert_cable1_anchorage)
set_vert_cable1_midspan = myAssembly.Set(name = 'setVertices Cable1_Midspan', vertices = vert_cable1_midspan)
set_vert_cable2_anchorage = myAssembly.Set(name = 'setVertices Cable2_Anchorage', vertices = vert_cable2_anchorage)
set_vert_cable2_midspan = myAssembly.Set(name = 'setVertices Cable2_Midspan', vertices = vert_cable2_midspan)

bridge.PinnedBC(createStepName = 'Initial', localCsys = None, name = 'anchorageBC1', region = set_vert_cable1_anchorage)
constraint_midspan1 = bridge.DisplacementBC(createStepName = 'Initial', name = 'midspanBC1', region = set_vert_cable1_midspan, u2 = 0)
bridge.PinnedBC(createStepName = 'Initial', localCsys = None, name = 'anchorageBC2', region = set_vert_cable2_anchorage)
constraint_midspan2 = bridge.DisplacementBC(createStepName = 'Initial', name = 'midspanBC2', region = set_vert_cable2_midspan, u2 = 0)

# MESH
cable1.seedPart(size=sz_cables, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
cable1.setElementType(regions=set_cable1, elemTypes=(elemType1,))
cable1.generateMesh()

cable2.seedPart(size=sz_cables, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
cable2.setElementType(regions=set_cable2, elemTypes=(elemType1,))
cable2.generateMesh()
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ GIRDER -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='Girder', dimensionality=THREE_D, type=DEFORMABLE_BODY)
girder = bridge.parts['Girder']
girder.WirePolyLine(points=deck, mergeType=SEPARATE, meshable=ON)

# PART SETS
set_girder = bridge.parts['Girder'].Set(name = 'Girder set', edges = girder.edges)

# SECTION ASSIGNMENT
# bridge.GeneralizedProfile(name='profileGirder', area=1.2338, i11=3.42, i12=0.0, i22=1.21e+2, j=9.42492, gammaO=0.0,  gammaW=0.0)             # STEEL
bridge.GeneralizedProfile(name='profileGirder', area=1.67, i11=9.91, i12=0.0, i22=184, j=31.1, gammaO=0.0,  gammaW=0.0)
Emat3= Ematgirder
Gmat3=Emat3/(2*(1+0.3))
mySection=bridge.BeamSection(name='sectionGirder', profile='profileGirder',									
    poissonRatio=0.3, integration=BEFORE_ANALYSIS,
	table=((Emat3, Gmat3), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
	consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
	temperatureDependency=OFF, thermalExpansion=OFF, density = Densitygirder)

bridge.parts['Girder'].SectionAssignment(region = set_girder, sectionName = 'sectionGirder')
bridge.parts['Girder'].assignBeamSectionOrientation(region = set_girder, method = N1_COSINES, n1 = (0.0, 1.0, 0.0))

# ASSEMBLY
inst_girder = myAssembly.Instance(name='Girder instance', part=girder, dependent=ON)

# BCs
vert_girder_ends = inst_girder.vertices.findAt(((deck[0]), ), ((deck[-1]), ),) 
set_vert_girder_ends = myAssembly.Set(name = 'setVertices Girder_Ends', vertices = vert_girder_ends)
# bridge.DisplacementBC(createStepName = 'Initial', localCsys = None, name = 'girderBCs', region = set_vert_girder_ends, u1 = 0, u2 = 0, u3 = 0, ur1 = 0)

# MESH
girder.seedPart(size=sz_girder, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B32)
girder.setElementType(regions=set_girder, elemTypes=(elemType1,))
girder.generateMesh()
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ HANGERS ----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='Hangers', dimensionality=THREE_D, type=DEFORMABLE_BODY)
hangers = bridge.parts['Hangers']

startindex = np.argmax(z1_main)+1
sluttindex = len(z1_main)-1-np.argmax(z1_main)
for i in range(startindex, sluttindex):
	punkt2_cable1 = list(cable1.vertices[i].pointOn[0])
	punkt2_cable1[-1]= list(girder.vertices[-76+6*i].pointOn[0])[-1]+1.5
	punkt2_cable1[1]=h/2
	hangers.WirePolyLine(points = (list(cable1.vertices[i].pointOn[0]), punkt2_cable1), mergeType = IMPRINT, meshable = ON)

	punkt2_cable2 = list(cable2.vertices[i].pointOn[0])
	punkt2_cable2[-1]= list(girder.vertices[-76+6*i].pointOn[0])[-1]+1.5
	punkt2_cable2[1]=-h/2
	hangers.WirePolyLine(points = (list(cable2.vertices[i].pointOn[0]), punkt2_cable2), mergeType = IMPRINT, meshable = ON)
	
# PART SETS
set_hangers = bridge.parts['Hangers'].Set(name = 'Hangers set', edges = hangers.edges)

# SECTION ASSIGNMENT
bridge.GeneralizedProfile(name='profileHangers', area=0.0017, i11=2.2e-7, i12=0.0, i22=2.2e-6, j=4.4e-7, gammaO=0.0,  gammaW=0.0)
Emat=210e9
Gmat=Emat/(2*(1+0.3))
mySection=bridge.BeamSection(name='sectionHangers', profile='profileHangers',									
    poissonRatio=0.3, integration=BEFORE_ANALYSIS,
	table=((Emat, Gmat), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
	consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
	temperatureDependency=OFF, thermalExpansion=OFF, density = 7850.0)
	
bridge.parts['Hangers'].SectionAssignment(region = set_hangers, sectionName = 'sectionHangers')
bridge.parts['Hangers'].assignBeamSectionOrientation(region = set_hangers, method = N1_COSINES, n1 = (0.0, 1.0, 0.0))

# ASSEMBLY
inst_hangers = myAssembly.Instance(name='Hangers instance', part=hangers, dependent=ON)

# MESH
hangers.seedPart(size=sz_hangers, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
hangers.setElementType(regions=set_hangers, elemTypes=(elemType1,))
hangers.generateMesh()

myAssembly.regenerate()
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ CONNECTION ELEMENTS TOWERTOPS ------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# Indexes 
indeks_tower1_top = np.argmax(pylon1_z)
indeks_tower2_top = np.argmax(pylon2_z)
indeks_tower1_cable1_top = len(z1_main)-1-np.argmax(z1_main)
indeks_tower1_cable2_top = len(z2_main)-1-np.argmax(z2_main)
indeks_tower2_cable1_top = np.argmax(z1_main)
indeks_tower2_cable1_top = np.argmax(z2_main)

# PART CREATION
bridge.Part(name='ConelTowers', dimensionality=THREE_D, type=DEFORMABLE_BODY)
coneltowers = bridge.parts['ConelTowers']
coneltowers.WirePolyLine(points = (cable1.vertices[indeks_tower1_cable1_top].pointOn[0], tower1.vertices[indeks_tower1_top].pointOn[0], cable2.vertices[indeks_tower1_cable2_top].pointOn[0]), mergeType = IMPRINT, meshable = ON)
coneltowers.WirePolyLine(points = (cable1.vertices[indeks_tower2_cable1_top].pointOn[0], tower2.vertices[indeks_tower2_top].pointOn[0], cable2.vertices[indeks_tower2_cable1_top].pointOn[0]), mergeType = IMPRINT, meshable = ON)

# PART SETS
set_coneltowers = bridge.parts['ConelTowers'].Set(name = 'ConelTowers set', edges = coneltowers.edges)

# SECTION ASSIGNMENT
bridge.GeneralizedProfile(name='profileConelTowers', area=0.22, i11=1000.0, i12=0.0, i22=1000.0, j=1000.0, gammaO=0.0,  gammaW=0.0)
Emat3=2.00000e+11
Gmat3=Emat3/(2*(1+0.3))
mySection=bridge.BeamSection(name='sectionConelTowers', profile='profileConelTowers',									
    poissonRatio=0.3, integration=BEFORE_ANALYSIS,
	table=((Emat3, Gmat3), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
	consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
	temperatureDependency=OFF, thermalExpansion=OFF, density = 0.0)

bridge.parts['ConelTowers'].SectionAssignment(region = set_coneltowers, sectionName = 'sectionConelTowers')
bridge.parts['ConelTowers'].assignBeamSectionOrientation(region = set_coneltowers, method = N1_COSINES, n1 = (0.0, 0.0, -1.0))

# ASSEMBLY
inst_coneltowers = myAssembly.Instance(name='ConelTowers instance', part=coneltowers, dependent=ON)

# MESH
coneltowers.seedPart(size=sz_coneltowers, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
coneltowers.setElementType(regions=set_coneltowers, elemTypes=(elemType1,))
coneltowers.generateMesh()
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ CONNECTION ELEMENTS GIRDER ---------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='ConelGirder', dimensionality=THREE_D, type=DEFORMABLE_BODY)
conelgirder = bridge.parts['ConelGirder']

sluttindex = len(z1_main)-1-2*np.argmax(z1_main)
for i in range(1, sluttindex):
	conelgirder_node1 = list(hangers.vertices[-2*i+205].pointOn[0])	
	conelgirder_node2 = list(girder.vertices[6*i-4].pointOn[0])
	conelgirder_node3 = list(hangers.vertices[2*i+203].pointOn[0])
	conelgirder.WirePolyLine(points = (conelgirder_node1, conelgirder_node2, conelgirder_node3), mergeType = IMPRINT, meshable = ON)
	
# PART SETS
set_conelgirder = bridge.parts['ConelGirder'].Set(name = 'ConelGirder set', edges = conelgirder.edges)

# SECTION ASSIGNMENT
bridge.GeneralizedProfile(name='profileConelGirder', area=0.22, i11=1000.0, i12=0.0, i22=1000.0, j=1000.0, gammaO=0.0,  gammaW=0.0)
Emat3=2.00000e+11
Gmat3=Emat3/(2*(1+0.3))
mySection=bridge.BeamSection(name='sectionConelGirder', profile='profileConelGirder',									
    poissonRatio=0.3, integration=BEFORE_ANALYSIS,
	table=((Emat3, Gmat3), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
	consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
	temperatureDependency=OFF, thermalExpansion=OFF, density = 0.0)

bridge.parts['ConelGirder'].SectionAssignment(region = set_conelgirder, sectionName = 'sectionConelGirder')
bridge.parts['ConelGirder'].assignBeamSectionOrientation(region = set_conelgirder, method = N1_COSINES, n1 = (0.0, 0.0, -1.0))

# ASSEMBLY
inst_conelgirder = myAssembly.Instance(name='ConelGirders instance', part=conelgirder, dependent=ON)

# MESH
conelgirder.seedPart(size=sz_conelgirder, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
conelgirder.setElementType(regions=set_conelgirder, elemTypes=(elemType1,))
conelgirder.generateMesh()
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TIES AT THE TOWER TOPS -------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# Indexes
indeks_tower1_top = np.argmax(pylon1_z)
indeks_tower2_top = np.argmax(pylon2_z)
indeks_tower1_cable1_top = len(z1_main)-1-np.argmax(z1_main)
indeks_tower1_cable2_top = len(z2_main)-1-np.argmax(z2_main)
indeks_tower2_cable1_top = np.argmax(z1_main)
indeks_tower2_cable2_top = np.argmax(z2_main)

# CONNECTION ELEMENT AT TOWER 1
# Top of tower to con.el
verticesMaster = inst_tower1.vertices.findAt(((inst_tower1.vertices[indeks_tower1_top].pointOn[0]), ) ,)
verticesSlave = inst_coneltowers.vertices.findAt(((inst_tower1.vertices[indeks_tower1_top].pointOn[0]), ) ,)
setMaster = myAssembly.Set(name = 'Master set 1', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 1', vertices = verticesSlave)
bridge.Tie(adjust=ON, master= setMaster, name='Constraint-1', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)

# Con.el to cable1
verticesMaster = inst_coneltowers.vertices.findAt(((inst_cable1.vertices[indeks_tower1_cable1_top].pointOn[0]), ), )
verticesSlave = inst_cable1.vertices.findAt(((inst_cable1.vertices[indeks_tower1_cable1_top].pointOn[0]), ) ,)
setMaster = myAssembly.Set(name = 'Master set 2', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 2', vertices = verticesSlave)
bridge.Tie(adjust=ON, master= setMaster, name='Constraint-2', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)

# Con.el to cable2
verticesMaster = inst_coneltowers.vertices.findAt(((inst_cable2.vertices[indeks_tower1_cable2_top].pointOn[0]), ), )
verticesSlave = inst_cable2.vertices.findAt(((inst_cable2.vertices[indeks_tower1_cable2_top].pointOn[0]), ) ,)
setMaster = myAssembly.Set(name = 'Master set 3', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 3', vertices = verticesSlave)
bridge.Tie(adjust=ON, master= setMaster, name='Constraint-3', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)

# CONNECTION ELEMENT AT TOWER 2
# Top of tower to con.el
verticesMaster = inst_tower2.vertices.findAt(((inst_tower2.vertices[indeks_tower2_top].pointOn[0]), ) ,)
verticesSlave = inst_coneltowers.vertices.findAt(((inst_tower2.vertices[indeks_tower2_top].pointOn[0]), ) ,)
setMaster = myAssembly.Set(name = 'Master set 4', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 4', vertices = verticesSlave)
bridge.Tie(adjust=ON, master= setMaster, name='Constraint-4', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)

# Con.el to cable1
verticesMaster = inst_coneltowers.vertices.findAt(((inst_cable1.vertices[indeks_tower2_cable1_top].pointOn[0]), ), )
verticesSlave = inst_cable1.vertices.findAt(((inst_cable1.vertices[indeks_tower2_cable1_top].pointOn[0]), ) ,)
setMaster = myAssembly.Set(name = 'Master set 5', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 5', vertices = verticesSlave)
bridge.Tie(adjust=ON, master= setMaster, name='Constraint-5', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)

# Con.el to cable2
verticesMaster = inst_coneltowers.vertices.findAt(((inst_cable2.vertices[indeks_tower2_cable2_top].pointOn[0]), ), )
verticesSlave = inst_cable2.vertices.findAt(((inst_cable2.vertices[indeks_tower2_cable2_top].pointOn[0]), ) ,)
setMaster = myAssembly.Set(name = 'Master set 6', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 6', vertices = verticesSlave)
bridge.Tie(adjust=ON, master= setMaster, name='Constraint-6', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TIES AT THE RIGELS -----------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# Rigel 1: positive y-value
verticesMaster = inst_tower1.vertices.findAt(((punkt1_tower1), ), )
verticesSlave = inst_rigel1.vertices.findAt(((punkt1_tower1), ), )
setMaster = myAssembly.Set(name = 'Master set 7', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 7', vertices = verticesSlave)
bridge.Tie(adjust=ON, master= setMaster, name='Constraint-7', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)

# Rigel 1: negative y-value
verticesMaster = inst_tower1.vertices.findAt(((punkt2_tower1), ), )
verticesSlave = inst_rigel1.vertices.findAt(((punkt2_tower1), ), )
setMaster = myAssembly.Set(name = 'Master set 8', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 8', vertices = verticesSlave)
bridge.Tie(adjust=ON, master= setMaster, name='Constraint-8', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)

# Rigel 2: positive y-value
verticesMaster = inst_tower2.vertices.findAt(((punkt1_tower2), ), )
verticesSlave = inst_rigel2.vertices.findAt(((punkt1_tower2), ), )
setMaster = myAssembly.Set(name = 'Master set 9', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 9', vertices = verticesSlave)
bridge.Tie(adjust=ON, master= setMaster, name='Constraint-9', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)

# Rigel 2: negative y-value
verticesMaster = inst_tower2.vertices.findAt(((punkt2_tower2), ), )
verticesSlave = inst_rigel2.vertices.findAt(((punkt2_tower2), ), )
setMaster = myAssembly.Set(name = 'Master set 10', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 10', vertices = verticesSlave)
bridge.Tie(adjust=ON, master= setMaster, name='Constraint-10', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ EQUATION AND SPRING STIFFNESS AT GIRDER ENDS ---------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# Rigel 1: center to girder
verticesMaster = inst_rigel1.vertices.findAt(((deck[0]), ), )
verticesSlave = inst_girder.vertices.findAt(((deck[0]), ), )
setMaster = myAssembly.Set(name = 'Master set 11', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 11', vertices = verticesSlave)
#bridge.Tie(adjust=ON, master= setMaster, name='Constraint-11', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)
bridge.Equation(name = 'eq1', terms = ((1.0, 'Master set 11', 3,), (-1.0, 'Slave set 11', 3,)))			# constrained in z-direction
bridge.Equation(name = 'eq2', terms = ((1.0, 'Master set 11', 2,), (-1.0, 'Slave set 11', 2,)))			# constrained in y-direction
bridge.Equation(name = 'eq3', terms = ((1.0, 'Master set 11', 4,), (-1.0, 'Slave set 11', 4,)))			# constrained in torsional direction

#Horizontal translational spring at rigel1
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-1', regionPairs=region, axis=FIXED_DOF, dof1 = 1, dof2 = 1, 
    springBehavior=ON, springStiffness=1291200000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

# Rigel 2: center to girder
verticesMaster = inst_rigel2.vertices.findAt(((deck[-1]), ), )
verticesSlave = inst_girder.vertices.findAt(((deck[-1]), ), )
setMaster = myAssembly.Set(name = 'Master set 12', vertices = verticesMaster)
setSlave = myAssembly.Set(name = 'Slave set 12', vertices = verticesSlave)
#bridge.Tie(adjust=ON, master= setMaster, name='Constraint-12', positionToleranceMethod=COMPUTED, slave= setSlave, thickness=ON, tieRotations=ON)
bridge.Equation(name = 'eq4', terms = ((1.0, 'Master set 12', 3,), (-1.0, 'Slave set 12', 3,)))			# constrained in z-direction
bridge.Equation(name = 'eq5', terms = ((1.0, 'Master set 12', 2,), (-1.0, 'Slave set 12', 2,)))			# constrained in y-direction
bridge.Equation(name = 'eq6', terms = ((1.0, 'Master set 12', 4,), (-1.0, 'Slave set 12', 4,)))			# constrained in torsional direction

#Horizontal translational spring at rigel2
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-2', regionPairs=region, axis=FIXED_DOF, dof1 = 1, dof2 = 1, 
    springBehavior=ON, springStiffness=1291200000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TIES ALONG THE GIRDER --------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
sluttindex = len(z1_main)-1-2*np.argmax(z1_main)
for i in range(1, sluttindex):
	verticesMaster_girder = inst_girder.vertices.findAt((girder.vertices[6*i-4].pointOn[0], ) ,)
	verticesSlave_conelgirder = inst_conelgirder.vertices.findAt((girder.vertices[6*i-4].pointOn[0], ) ,)
	setMaster_girder = myAssembly.Set(name='Master set 7-'+str(i), vertices=(verticesMaster_girder))		
	setSlave_conelgirder = myAssembly.Set(name='Slave set 7-'+str(i), vertices=(verticesSlave_conelgirder))
	bridge.Tie(adjust=ON, master= setMaster_girder, name='Constraint-'+str(i+99), positionToleranceMethod=SPECIFIED, 
		constraintEnforcement = NODE_TO_SURFACE, positionTolerance = 100.0, slave= setSlave_conelgirder, thickness=ON, tieRotations=ON)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TIES AT THE BOTTOM OF HANGERS ------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
sluttindex = len(z1_main)-1-2*np.argmax(z1_main)
# Underneath cable 1
for i in range(1, sluttindex):
	verticesMaster_conelgirder = inst_conelgirder.vertices.findAt((hangers.vertices[-2*i+205].pointOn[0], ) ,)
	verticesSlave_hanger = inst_hangers.vertices.findAt((hangers.vertices[-2*i+205].pointOn[0], ) ,)
	setMaster_conelgirder = myAssembly.Set(name='Master set 8-'+str(i), vertices=(verticesMaster_conelgirder))	
	setSlave_hanger = myAssembly.Set(name='Slave set 8-'+str(i), vertices=(verticesSlave_hanger))
	bridge.Tie(adjust=ON, master= setMaster_conelgirder, name='Constraint-'+str(i+210), positionToleranceMethod=SPECIFIED, 
		constraintEnforcement = NODE_TO_SURFACE, positionTolerance = 100.0, slave= setSlave_hanger, thickness=ON, tieRotations=ON)

# Underneath cable 2
for i in range(1, sluttindex):
	verticesMaster_conelgirder = inst_conelgirder.vertices.findAt((hangers.vertices[2*i+203].pointOn[0], ) ,)
	verticesSlave_hanger = inst_hangers.vertices.findAt((hangers.vertices[2*i+203].pointOn[0], ) ,)
	setMaster_conelgirder = myAssembly.Set(name='Master set 9-'+str(i), vertices=(verticesMaster_conelgirder))	
	setSlave_hanger = myAssembly.Set(name='Slave set 9-'+str(i), vertices=(verticesSlave_hanger))
	bridge.Tie(adjust=ON, master= setMaster_conelgirder, name='Constraint-'+str(i+320), positionToleranceMethod=SPECIFIED, 
		constraintEnforcement = NODE_TO_SURFACE, positionTolerance = 100.0, slave= setSlave_hanger, thickness=ON, tieRotations=ON)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TIES ON TOP OF HANGERS -------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------	
startindex = np.argmax(z1_main)
sluttindex = 114
# Along cable 1
for i in range(startindex, sluttindex):
	verticesMaster_cable1 = inst_cable1.vertices.findAt((cable1.vertices[i+1].pointOn[0], ) ,)
	verticesSlave_hanger = inst_hangers.vertices.findAt((hangers.vertices[-2*i+226].pointOn[0], ) ,)
	setMaster_cable1 = myAssembly.Set(name='Master set 10-'+str(i-11), vertices=(verticesMaster_cable1))
	setSlave_hanger = myAssembly.Set(name= 'Slave set 10-'+str(i-11), vertices=(verticesSlave_hanger))
	bridge.Tie(adjust=ON, master= setMaster_cable1, name='Constraint-'+str(i+488), positionToleranceMethod=SPECIFIED, 
		constraintEnforcement = NODE_TO_SURFACE, positionTolerance = 100.0, slave= setSlave_hanger, thickness=ON, tieRotations=ON)

# Along cable 2	
for i in range(startindex, sluttindex):
	verticesMaster_cable2 = inst_cable2.vertices.findAt((cable2.vertices[i+1].pointOn[0], ) ,)
	verticesSlave_hanger = inst_hangers.vertices.findAt((hangers.vertices[2*i+180].pointOn[0], ) ,)
	setMaster_cable2 = myAssembly.Set(name='Master set 11-'+str(i-11), vertices=(verticesMaster_cable2))
	setSlave_hanger = myAssembly.Set(name= 'Slave set 11-'+str(i-11), vertices=(verticesSlave_hanger))
	bridge.Tie(adjust=ON, master= setMaster_cable2, name='Constraint-'+str(i+688), positionToleranceMethod=SPECIFIED, 
		constraintEnforcement = NODE_TO_SURFACE, positionTolerance = 100.0, slave= setSlave_hanger, thickness=ON, tieRotations=ON)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ STEP 1 -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# Create step
bridge.StaticStep(name='step1', previous='Initial', nlgeom=ON, initialInc = 0.001, timePeriod = 1, minInc = 1e-7)  
bridge.FieldOutputRequest(name='F-Output-2', createStepName='step1', variables=('SF', 'U'), region = MODEL, frequency = 1)

# TOWERS LOADING
edges1 = inst_tower1.edges
edges2 = inst_tower2.edges
set_edges_towers = myAssembly.Set(edges=edges1+edges2, name='SetEdges towers')
last1 = bridge.Gravity(name='Gravity load towers', createStepName='step1', comp3=-9.81, distributionType=UNIFORM, field='', region = set_edges_towers)

# RIGELS LOADING
edges1 = inst_rigel1.edges
edges2 = inst_rigel2.edges
set_edges_rigels = myAssembly.Set(edges=edges1+edges2, name='SetEdges rigels')
last1 = bridge.Gravity(name='Gravity load rigels', createStepName='step1', comp3=-9.81, distributionType=UNIFORM, field='', region = set_edges_rigels)

#model change, remove: cables, girder, hangers, conelgirder
edges1 = inst_cable1.edges
edges2 = inst_cable2.edges
edges3 = inst_girder.edges
edges4 = inst_hangers.edges
edges5 = inst_coneltowers.edges
edges6 = inst_conelgirder.edges

set_modelchange1 = myAssembly.Set(edges=edges1+edges2+edges3+edges4+edges5+edges6, name='Set-modelchange1')
mdb.models['Model-1'].ModelChange(name = 'modelchange step 1', createStepName = 'step1', region = set_modelchange1)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ STEP 2 -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# Create step
bridge.StaticStep(name='step2', previous='step1', nlgeom=ON, initialInc = 0.001, timePeriod = 1, minInc = 1e-7, maxNumInc = 500, matrixSolver = DIRECT)  
bridge.FieldOutputRequest(name='F-Output-2', createStepName='step2', variables=('SF', 'U'), region = MODEL) #, frequency = 1)

#model change, add: cables
edges1 = inst_cable1.edges
edges2 = inst_cable2.edges
edges3 = inst_coneltowers.edges
set_modelchange2 = myAssembly.Set(edges=edges1+edges2+edges3, name='Set-modelchange2')
mdb.models['Model-1'].ModelChange(name = 'modelchange step 2', createStepName = 'step2', region = set_modelchange2, activeInStep = ON)

# CABLE LOADING
edges1 = inst_cable1.edges
edges2 = inst_cable2.edges
set_edges_cables = myAssembly.Set(edges=edges1+edges2, name='SetEdges cables')
last2 = bridge.Gravity(name='Gravity load cables', createStepName='step2', comp3=-9.81, distributionType=UNIFORM, field='', region = set_edges_cables)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ STEP 3 -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# Create step
bridge.StaticStep(name='step3', previous='step2', nlgeom=ON, initialInc = 0.001, timePeriod = 1, minInc = 1e-7, maxNumInc = 500, matrixSolver = DIRECT)  
bridge.FieldOutputRequest(name='F-Output-2', createStepName='step3', variables=('SF', 'U'), region = MODEL) #, frequency = 1)

#model change, add: girder, con.el.girder and hangers
edges1 = inst_girder.edges
edges2 = inst_conelgirder.edges
edges3 = inst_hangers.edges
set_modelchange3 = myAssembly.Set(edges=edges1+edges2+edges3, name='Set-modelchange3')
mdb.models['Model-1'].ModelChange(name = 'modelchange step 3', createStepName = 'step3', region = set_modelchange3, activeInStep = ON)

# GIRDER LOADING 
edges = inst_girder.edges
set_edges_girder = myAssembly.Set(edges=edges, name='SetEdges girder')
last3 = bridge.Gravity(name='Gravity load girder', createStepName='step3', comp3=-9.81, distributionType=UNIFORM, field='', region = set_edges_girder)

# HANGERS LOADING 
edges = inst_hangers.edges
set_edges_hangers = myAssembly.Set(edges=edges, name='SetEdges hangers')
last4 = bridge.Gravity(name='Gravity load hangers', createStepName='step3', comp3=-9.81, distributionType=UNIFORM, field='', region = set_edges_hangers)

# Remove the BC at the midspan of the bridge
constraint_midspan1.setValuesInStep(stepName = 'step3', u2 = FREED)
constraint_midspan2.setValuesInStep(stepName = 'step3', u2 = FREED)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ STEP 5 -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
bridge.FrequencyStep(name = 'stepModal', previous = 'step3', eigensolver = LANCZOS, numEigen = 100)
bridge.FieldOutputRequest(name = 'F-Output-frequency', createStepName = 'stepModal', variables = ('SF', 'U', 'COORD'), region = MODEL)
#bridge.HistoryOutputRequest(name = 'H-Output-frequency', createStepName = 'stepModal', variables = ('SF', 'U', 'UR'), region = MODEL)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ NODE NUMBERING AND PATH ------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
a = mdb.models['Model-1'].rootAssembly

# GIRDER
a.makeIndependent(instances=(a.instances['Girder instance'], ))
partInstances =(a.instances['Girder instance'], )
a.setMeshNumberingControl(instances=partInstances, startNodeLabel=10000, 
    startElemLabel=10000)
session.Path(name='Path-girder', type=NODE_LIST, expression=(('Girder instance', ('10001:10306', )), ))

# CABLE 1 (positive y-values)
a.makeIndependent(instances=(a.instances['Cable1 instance'], ))
partInstances =(a.instances['Cable1 instance'], )
a.setMeshNumberingControl(instances=partInstances, startNodeLabel=20000, 
    startElemLabel=20000)
session.Path(name='Path-cable1', type=NODE_LIST, expression=(('Cable1 instance', ('20001:20076', )), ))

# CABLE 2 (negative y-values)
a.makeIndependent(instances=(a.instances['Cable2 instance'], ))
partInstances =(a.instances['Cable2 instance'], )
a.setMeshNumberingControl(instances=partInstances, startNodeLabel=30000, 
    startElemLabel=30000)


#Node set
#m = mdb.model['Model-1']
#rA = m.rootAssembly
#rA.Set(name = 'all_nodes',nodes = reduce(lambda a,b : a+b,[rA.instances[key].nodes[:]for key in rA.instances.keys()]))



#girdernodes = myAssembly.nodes

myAssembly.Set(name = 'Girder nodes', nodes = inst_girder.nodes[:])
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ ADD BEAM GIRDER INERTIA ------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------

mdb.models['Model-1'].keywordBlock.synchVersions(storeNodesAndElements=False)
mdb.models['Model-1'].keywordBlock.replace(111, """
*Beam General Section, elset=\"Girder set\", poisson = 0.3, density=0., section=GENERAL
1.67, 9.91, 0., 184, 31.2
0.,1.,0.
7e+10, 2.69231e+10
*BEAM ADDED INERTIA
4509, 	0., 		0., 	0., 	26757, 	496800, 	0. 
1677, 	0., 		0., 	0., 	4244, 	33654, 	    0.
5580, 	0., 		2.42685, 	0., 	2.976, 		446865, 	0.
32, 	-15.5, 	2.15435, 	0., 	0., 	0., 		0.
32, 	15.5, 	2.15435	, 	0., 	0., 	0., 		0.
400,    0.,         0.,     0.,     0.,     0.,   0.""")
"""
From above
1: Aluminium girder
2: Aluminium diaphragmas
3: Asphalt
4: Hanger heads left
5: Hanger heads right
6: Other equipment
"""

mdb.models['Model-1'].keywordBlock.insert(3395, """
*OUTPUT, HISTORY
*NODE PRINT, nset = "Girder nodes"
COORD, U, UR""")


# mdb.models['Model-1'].keywordBlock.insert(1860, """
# *Output, field, variable=PRESELECT
# *NODE PRINT, nset="ASSEMBLY_Girder_Girder set" """)

# \"ASSEMBLY_Girder instance_Girder set\"
# ASSEMBLY_Girder instance_Girder set
# Girder set
# \"Girder instance\"
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ CREATE JOB -------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
os.chdir(workDir)
myJob=mdb.Job(name=jobName, model='Model-1', multiprocessingMode=DEFAULT, numCpus=4, numDomains=4, numGPUs=0)
myJob.submit(consistencyChecking=OFF)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ END --------------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
#endring2